@@ -3,7 +3,7 @@ package Config::Perl;
 use warnings;
 use strict;
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 =head1 Name
 
@@ -15,6 +15,11 @@ subset of Perl and (limited) undumping of data structures (via PPI, not eval)
 =for comment
 Remember to test this by copy/pasting to/from 91_author_pod.t
 
+=for comment
+TODO Later: metacpan strips the extra space from the front of the code sample,
+so the extra space we added in ' END_CONFIG_FILE' breaks the script...
+search.cpan.org keeps the space there. What's the best solution?
+
  use Config::Perl;
  my $parser = Config::Perl->new;
  my $data = $parser->parse_or_die( \<<' END_CONFIG_FILE' );
@@ -36,7 +41,7 @@ Remember to test this by copy/pasting to/from 91_author_pod.t
 The goal of this module is to support the parsing of a small subset of Perl,
 primarily in order to parse configuration files written in that subset of Perl.
 As a side effect, this module can "undump" some data structures written by
-L<Data::Dumper|Data::Dumper> and L<Data::Dump|Data::Dump>, but
+L<Data::Dumper|Data::Dumper>, but
 please make sure to read L<Data::Undump::PPI> for details!
 
 The code is parsed via L<PPI|PPI>, eliminating the need for Perl's C<eval>.
@@ -57,7 +62,7 @@ or adding an error message that the particular feature is unsupported.
 However, the result of using this module to parse something that is not valid Perl is undefined;
 it may cause an error, or may fail in some other silent way.
 
-This document describes version 0.04 of the module.
+This document describes version 0.06 of the module.
 Although this module has a fair number of tests, it still lacks some
 features (see list below) and there may be bugs lurking.
 Contributions are welcome!
@@ -116,7 +121,7 @@ arrayrefs and hashrefs constructed via C<[]> and C<{}> resp.
 =item *
 
 declarations - only C<our>, also C<my> on the outermost level (document)
-where it is treated exactly like C<our>;
+where it is currently treated exactly like C<our>;
 not supported are lexical C<my> inside blocks, C<local> or C<state>
 
 =item *
@@ -173,7 +178,8 @@ conditionals, like for example a very simple C<if ($^O eq 'linux') { ... }> (may
 
 =item *
 
-any functions (mostly this is "no"; supporting a very small subset of functions, e.g. C<push>, is "maybe")
+any functions, including C<bless>
+(mostly this is "no"; supporting a very small subset of functions, e.g. C<push>, is "maybe")
 
 =item *
 
